@@ -6,3 +6,6 @@ PROTOCOL = 'https'
 DOMAIN = 'a2.wykop.pl'
 
 CLIENT_NAME = 'wykop-sdk-reborn'
+
+ANDROID_APPKEY = 'aNd401dAPp'
+ANDROID_MIKROBLOG_PLUS_APPKEY = 'd99b6pFK8f'
